import time

from .bcp_realtime import get_data, format_data


def run_mini_viewer():
    data = get_data()
    data = format_data(data)

    print(
        "IMPORTANT: Data is by BCP GmbH and is under CC BY-NC 4.0\nIt can be found here: https://opendata.bonn.de/dataset/parkh%C3%A4user-und-parkpl%C3%A4tze-realtime-belegung"
    )
    print(f"Time: {data[0]['timestamp_time']}")
    print(f"ID  |  Title  | Total | Free | Used | Status")

    for i in data:
        print(
            f"{i['id']} | {i['title']} | {i['parking_spots_total']} | {i['parking_spots_free']} | {i['parking_spots_used']} | {i['status']}"
        )



from .bcp_realtime import get_data, format_data
import time
import csv


class HistoryTracker:
    def __init__(self, time_to_repeat):
        self.time_to_repeat = time_to_repeat
        self.scheme = [
            "parking_spots_total",
            "parking_spots_free",
            "parking_spots_used",
            "time",
            "date",
        ]
        if self.time_to_repeat < 60:
            raise Exception("The time to repeat is below 60.\nThis would spam the api.")

    def track_history_csv(self):
        data = get_data()
        data = format_data(data)
        for i in data:
            with open(f'{i["title"]}.csv', "w", newline="") as csvfile:
                writer = csv.DictWriter(csvfile, fieldnames=self.scheme)
                writer.writeheader()
        while True:
            data = get_data()
            data = format_data(data)
            for i in data:
                with open(f'{i["title"]}.csv', "a", newline="") as csvfile:
                    writer = csv.DictWriter(csvfile, fieldnames=self.scheme)
                    writer.writerow(
                        {
                            "parking_spots_total": int(i["parking_spots_total"]),
                            "parking_spots_free": int(i["parking_spots_free"]),
                            "parking_spots_used": int(i["parking_spots_used"]),
                            "time": i["timestamp_time"],
                            "date": i["timestamp_date"],
                        }
                    )
            time.sleep(self.time_to_repeat)



import requests
import xmltodict

# Data is by BCP GmbH under CC BY-NC 4.0 and it's here https://opendata.bonn.de/dataset/parkh%C3%A4user-und-parkpl%C3%A4tze-realtime-belegung


def get_data():
    """
    Get the xml data from the bcp bonn api and make the data to dictionarys
    """
    data_unformatted = requests.get(
        "https://www.bcp-bonn.de/stellplatz/bcpext.xml"
    ).content
    data = xmltodict.parse(data_unformatted)
    return data


def format_data(data):
    """
    Format the data so that we only have, what we need
    """
    end_data = []
    for i in data["parkhaeuser"]["parkhaus"]:
        end_data.append(
            {
                "id": i["lfdnr"],
                "title": i["bezeichnung"],
                "parking_spots_total": int(i["gesamt"]),
                "parking_spots_free": int(i["frei"]),
                "parking_spots_used": int(i["gesamt"]) - int(i["frei"]),
                "status": i["status"],
                "timestamp_time": i["zeitstempel"].split()[1],
                "timestamp_date": i["zeitstempel"].split()[0],
            }
        )
    return end_data
